@@ -57,6 +57,8 @@ OC.L10N.register(
     "Untitled item" : "بند غير معنون",
     "Unknown calendar" : "تقويم غير معروف",
     "Could not update calendar order." : "لا يمكن تحديث ترتيب التقويم.",
+    "Internal link" : "الرابط الداخلي",
+    "Copy internal link" : "انسخ الرابط الداخلي",
     "Share link" : "رابط المشاركة",
     "Copy public link" : "نسخ الرابط العام",
     "Send link to calendar via email" : "ارسال رابط التقويم عبر البريد",
@@ -75,12 +77,11 @@ OC.L10N.register(
     "Unpublishing calendar failed" : "فشل في الغاء نشر التقويم",
     "can edit" : "يمكن التحرير",
     "Unshare with {displayName}" : "الغاء المشاركة مع {displayName}",
-    "An error occurred, unable to change the unshare the calendar." : "حدث خطأ، لا يمكن تعديل نشر التقويم",
     "An error occurred, unable to change the permission of the share." : "حدث خطأ، لا يمكن تعديل صلاحيات نشر التقويم.",
     "Share with users or groups" : "شارك مع مستخدمين او مجموعات",
     "No users or groups" : "لا يوجد مستخدمين أو مجموعات",
-    "Copy private link" : "نسخ الرابط الخاص",
     "Unshare from me" : "أنت ألغيت المشاركة",
+    "Save" : "حفظ",
     "Import calendars" : "استيراد التقويم",
     "Please select a calendar to import into …" : "يرجى اختيار تقويم للاستيراد اليه  …",
     "Filename" : "اسم الملف",
@@ -106,7 +107,6 @@ OC.L10N.register(
     "Enable birthday calendar" : "تفعيل تقويم عيد الميلاد",
     "Show tasks in calendar" : "اظهار المهام في التقويم",
     "Enable simplified editor" : "تفعيل المحرر البسيط",
-    "Limit visible events per view" : "حصر رؤية الفعاليات بالمشاهدة",
     "Show weekends" : "اظهار ايام نهاية الاسبوع",
     "Show week numbers" : "اظهار ارقام الأسابيع",
     "Copy primary CalDAV address" : "نسخ عنوان CalDAV الرئيسي",
@@ -127,7 +127,6 @@ OC.L10N.register(
     "Friday" : "الجمعة",
     "Saturday" : "السبت",
     "Sunday" : "الأحد",
-    "Save" : "حفظ",
     "Update" : "حدث",
     "Your email address" : "عنوان بريديك الإلكتروني",
     "before at" : "قبل",
@@ -269,7 +268,6 @@ OC.L10N.register(
     "Untitled event" : "فعالية بدون اسم",
     "Untitled task" : "مهمة بدون اسم",
     "Please ask your administrator to enable the Tasks App." : "تواصل مع مسؤول النظام لاستخدام تطبيق المهام.",
-    "Next" : "التالي",
     "%n more" : "%n المزيد",
     "No events to display" : "لا يوجد فعاليات",
     "No events" : "لا يوجد فعاليات",
