@@ -69,12 +69,11 @@ OC.L10N.register(
     "Unpublishing calendar failed" : "Diembannaadur an deizataer c'hwited",
     "can edit" : "posuple eo embann",
     "Unshare with {displayName}" : "Dirannañ gant {displayName}",
-    "An error occurred, unable to change the unshare the calendar." : "Ur fazi a zo bet, dibosupl eo cheñch an deizataer dirannet.",
     "An error occurred, unable to change the permission of the share." : "Ur azi a zo bet, dibosupl eo cheñch aotreoù ar rannadenn.",
     "Share with users or groups" : "Rannañ gant implijourienn pe strolladoù",
     "No users or groups" : "Implijourienn pe strodadoù ebet",
-    "Copy private link" : "Eilañ al liamm prevez",
     "Unshare from me" : "Paouez da lodañ ganin",
+    "Save" : "Enrollañ",
     "Import calendars" : "Emporzhiañ deizataerioù",
     "Please select a calendar to import into …" : "Choazit un deizataer de emporzhiañ e-barzh ...",
     "Filename" : "Anv restr",
@@ -90,7 +89,6 @@ OC.L10N.register(
     "Description" : "Deskrivadur",
     "Add" : "Ouzhpennañ",
     "Monday" : "Lun",
-    "Save" : "Enrollañ",
     "Update" : "Hizivaat",
     "Your email address" : "O chom-lec'h postel",
     "Notification" : "Kemenadenn",
@@ -125,7 +123,6 @@ OC.L10N.register(
     "_Every %n month_::_Every %n months_" : ["Bep miz","Bep %n viz","Bep %n miz","Bep %n miz","Bep %n miz"],
     "_Every %n year_::_Every %n years_" : ["Bep bloaz","Bep %n vloaz","Bep %n bloaz","Bep %n bloaz","Bep %n bloaz"],
     "_on {weekday}_::_on {weekdays}_" : ["d'al {weekday}","d'ar {weekday}","d'ar {weekday}","d'ar {weekday}","d'ar {weekday}"],
-    "Next" : "Da heul",
     "%n more" : "%n ouzhpenn",
     "No events to display" : "Darvoud ebet da ziskouez",
     "No events" : "Darvoud ebet",
