@@ -58,6 +58,8 @@ OC.L10N.register(
     "Restore" : "بازیابی",
     "Delete permanently" : "حذف قطعی",
     "Empty trash bin" : "خالی کردن سطل زباله",
+    "Internal link" : "پیوند داخلی",
+    "Copy internal link" : "کپی کردن پیوند داخلی",
     "Share link" : "لینک را به اشتراک بگذارید",
     "Copy public link" : "پیوند عمومی را کپی کنید",
     "Send link to calendar via email" : "ارسال پیوند به تقویم از طریق ایمیل",
@@ -76,12 +78,11 @@ OC.L10N.register(
     "Unpublishing calendar failed" : "عدم انتشار تقویم موفقیت آمیز نبود",
     "can edit" : "می توان ویرایش کرد",
     "Unshare with {displayName}" : "عدم اشتراک گذاری با {displayName}",
-    "An error occurred, unable to change the unshare the calendar." : "خطایی روی داد ، قادر به تغییر تقویم عدم اشتراک گذاری نیست.",
     "An error occurred, unable to change the permission of the share." : "خطایی روی داد ، قادر به تغییر مجوز اشتراک نیست.",
     "Share with users or groups" : "اشتراک گذاری با کاربران یا گروه ها ...",
     "No users or groups" : "هیچ کاربر یا گروهی وجود ندارد",
-    "Copy private link" : "کپی کردن پیوند خصوصی",
     "Unshare from me" : "بی خبر از من",
+    "Save" : "ذخیره",
     "Import calendars" : "وارد کردن تقویم ها",
     "Please select a calendar to import into …" : "لطفاً یک تقویم را برای وارد کردن به… انتخاب کنید",
     "Filename" : "نام فایل",
@@ -116,7 +117,6 @@ OC.L10N.register(
     "Friday" : "جمعه",
     "Saturday" : "شنبه",
     "Sunday" : "یکشنبه",
-    "Save" : "ذخیره",
     "Update" : "به روز رسانی",
     "Your email address" : "پست الکترونیکی شما",
     "before at" : "قبل از در",
@@ -206,6 +206,7 @@ OC.L10N.register(
     "Please enter a valid date" : "لطفا یک تاریخ معتبر وارد کنید",
     "Please enter a valid date and time" : "لطفاً یک تاریخ و زمان معتبر وارد کنید",
     "Global" : "عمومی",
+    "Subscribe" : "اشتراک گذاری",
     "Personal" : "شخصی",
     "No more events today" : "هیچ رویداد دیگری برای امروز وجود ندارد",
     "No upcoming events" : "رویداد پیش‌رویی وجود ندارد",
@@ -263,9 +264,6 @@ OC.L10N.register(
     "until {untilDate}" : "تا زمان {untilDate}",
     "_%n time_::_%n times_" : ["%n بار","%n بارها"],
     "Untitled event" : "رویداد بدون عنوان",
-    "Prev" : "مقدمه",
-    "Next" : "بعدی",
-    "Year" : "سال",
     "No events to display" : "هیچ رویدادی برای نمایش وجود ندارد",
     "_+%n more_::_+%n more_" : ["+%n بیشتر","+%n بیشتر"],
     "No events" : "رویدادی وجود ندارد",
