@@ -5,7 +5,7 @@ OC.L10N.register(
     "%s has published the calendar »%s«" : "%s telah mempublikasikan kalender »%s«",
     "Unexpected error sending email. Please contact your administrator." : "Galat saat mengirim surel. Silakan hubungi administrator Anda.",
     "Hello," : "Halo,",
-    "We wanted to inform you that %s has published the calendar »%s«." : "Kami ingin menginformasikan anda bahwa %s telah mempublikasikan kalender »%s«.",
+    "We wanted to inform you that %s has published the calendar »%s«." : "Kami ingin menginformasikan Anda bahwa %s telah mempublikasikan kalender »%s«.",
     "Open »%s«" : "Buka »%s«",
     "Cheers!" : "Horee!",
     "Calendar" : "Kalender",
@@ -65,15 +65,15 @@ OC.L10N.register(
     "Unpublishing calendar failed" : "Gagal membatalkan penerbitan kalender",
     "can edit" : "dapat edit",
     "Unshare with {displayName}" : "Batal berbagi dengan {displayName}",
-    "An error occurred, unable to change the unshare the calendar." : "Terjadi galat, tidak dapat mengubah pembatalan berbagi kalender.",
     "An error occurred, unable to change the permission of the share." : "Terjadi galat, tidak dapat mengubah hak akses berbagi.",
     "Share with users or groups" : "Berbagi dengan pengguna atau grup",
     "No users or groups" : "Tidak ada pengguna atau grup",
-    "Copy private link" : "Salin tautan privat",
+    "Save" : "Simpan",
     "Import calendars" : "Impor kalender",
     "Filename" : "Nama berkas",
     "Cancel" : "Batal",
     "_Import calendar_::_Import calendars_" : ["Impor kalender"],
+    "Invalid location selected" : "Lokasi yang tidak valid dipilih",
     "No valid files found, aborting import" : "Berkas valid tidak ditemukan, impor dibatalkan",
     "Import partially failed. Imported {accepted} out of {total}." : "Sebagian impor gagal. Dari {total} hanya {accepted} berhasil impor.",
     "Automatic" : "Otomatis",
@@ -95,7 +95,6 @@ OC.L10N.register(
     "Enable birthday calendar" : "Aktifkan kalender ulang tahun",
     "Show tasks in calendar" : "Tampilkan tugas dalam kalender",
     "Enable simplified editor" : "Aktifkan editor serderhana",
-    "Limit visible events per view" : "Batasi acara terlihat per tampilan",
     "Show weekends" : "Tampilkan akhir pekan",
     "Show week numbers" : "Tampilkan nomor pekan",
     "Copy primary CalDAV address" : "Salin alamat utama CalDAV",
@@ -114,7 +113,6 @@ OC.L10N.register(
     "Friday" : "Jumat",
     "Saturday" : "Sabtu",
     "Sunday" : "Minggu",
-    "Save" : "Simpan",
     "Update" : "Perbarui",
     "Your email address" : "Alamat surel Anda",
     "Notification" : "Notifikasi",
@@ -187,6 +185,7 @@ OC.L10N.register(
     "Pick a date" : "Pilih tanggal",
     "Please enter a valid date" : "Silakan isi tanggal valid",
     "Please enter a valid date and time" : "Silakan isi tanggal dan waktu valid",
+    "Subscribe" : "Berlangganan",
     "Personal" : "Pribadi",
     "[Today]" : "[Hari ini]",
     "Details" : "Detail",
@@ -236,7 +235,6 @@ OC.L10N.register(
     "Untitled event" : "Acara tanpa judul",
     "Untitled task" : "Tugas tanpa judul",
     "Please ask your administrator to enable the Tasks App." : "Silakan tanya administrator Anda untuk mengaktifkan aplikasi Tugas.",
-    "Next" : "Berikutnya",
     "_+%n more_::_+%n more_" : ["+%n lagi"],
     "Other" : "Lainnya",
     "Add a location" : "Tambah lokasi",
@@ -256,7 +254,7 @@ OC.L10N.register(
     "An error occurred, unable to delete the calendar." : "Terjadi galat, tidak dapat menghapus kalender.",
     "Talk" : "Talk",
     "Review" : "Tinjauan",
-    "Mail" : "Email",
+    "Mail" : "Surel",
     "Birthday" : "Tanggal lahir"
 },
 "nplurals=1; plural=0;");
