@@ -28,6 +28,7 @@ OC.L10N.register(
     "Share link" : "ბმულის გაზიარება",
     "can edit" : "შეგიძლია შეცვლა",
     "Share with users or groups" : "გაზიარება მოხმარებლებთან ან ჯგუფებთან",
+    "Save" : "შენახვა",
     "Filename" : "ფაილის სახელი",
     "Cancel" : "უარყოფა",
     "Automatic" : "ავტომატური",
@@ -46,7 +47,6 @@ OC.L10N.register(
     "Friday" : "პარასკევი",
     "Saturday" : "შაბათი",
     "Sunday" : "კვირა",
-    "Save" : "შენახვა",
     "Update" : "განახლება",
     "Your email address" : "თქვენი ელ-ფოსტის მისამართი",
     "Notification" : "შეტყობინება",
@@ -65,6 +65,7 @@ OC.L10N.register(
     "available" : "ხელმისაწვდომი",
     "More" : "უფრო მეტი",
     "Global" : "გლობალური",
+    "Subscribe" : "გამოწერა",
     "Personal" : "პირადი",
     "Details" : "დეტლაები",
     "Attendees" : "დამსწრეები",
@@ -74,8 +75,6 @@ OC.L10N.register(
     "Week {number} of {year}" : "კვირა {number} {year}-დან",
     "Daily" : "ყოველდღიური",
     "Weekly" : "ყოველკვირეული",
-    "Prev" : "წინა",
-    "Next" : "შემდეგი",
     "Other" : "სხვა",
     "When shared show full event" : "როდესაც გაზიარებულია გამოჩნდეს სრული მოვლენა",
     "When shared show only busy" : "როდესაც გაზიარებულია გამოჩნდეს მხოლოდ დაკავებული",
