@@ -42,8 +42,10 @@ OC.L10N.register(
     "Copy public link" : "Copiar lo ligam public",
     "Copied code" : "Còdi copiat",
     "Could not copy code" : "Se poguèt pas copiar lo còdi",
+    "Delete share link" : "Suprimir lo ligam de partatge",
+    "Deleting share link …" : "Supression del ligam de partatge …",
     "can edit" : "pòt modificar",
-    "Copy private link" : "Copiar lo ligam privat",
+    "Save" : "Salvar",
     "Import calendars" : "Importar de calendièrs",
     "Filename" : "Nom de fichièr",
     "Cancel" : "Anullar",
@@ -71,7 +73,6 @@ OC.L10N.register(
     "Friday" : "Divendres",
     "Saturday" : "Dissabte",
     "Sunday" : "Dimenge",
-    "Save" : "Salvar",
     "Update" : "Metre a jorn",
     "Your name" : "Vòstre nom",
     "Your email address" : "Vòstra adreça electronica",
@@ -131,6 +132,7 @@ OC.L10N.register(
     "to {formattedDate}" : "cap a {formattedDate}",
     "Type to search time zone" : "Picar per cercar un fus orari",
     "Global" : "Global",
+    "Subscribe" : "S'abonar",
     "Personal" : "Personal",
     "Create a new event" : "Crear un eveniment novèl",
     "[Today]" : "[Uèi]",
@@ -159,8 +161,6 @@ OC.L10N.register(
     "_%n time_::_%n times_" : ["%n còp","%n còps"],
     "Untitled event" : "Eveniment sens nom",
     "Untitled task" : "Prètzfach sens nom",
-    "Next" : "Seguent",
-    "Year" : "Annada",
     "Other" : "Autre",
     "Add a location" : "Apondre un lòc",
     "Add a description" : "Apondre una descripcion",
